@@ -50,9 +50,9 @@ class scrollbar:
 
 
         #create arrows
-        self.scroll_surface.blit(g.picts["arrow.png"], (1, 1))
+        self.scroll_surface.blit(g.images["arrow.png"], (1, 1))
         self.scroll_surface.blit(pygame.transform.flip(
-                                g.picts["arrow.png"], 0, 1), (1, self.size[1]-17))
+                                g.images["arrow.png"], 0, 1), (1, self.size[1]-17))
 
         self.refresh_scroll(0, 100)
     def refresh_scroll(self, start_item, total_items):
@@ -82,23 +82,23 @@ class scrollbar:
             #If I want the gripper working, code here.
         return -1
     def adjust_pos(self, event, list_pos, item_list):
-        if event.type != pygame.MOUSEBUTTONUP: return list_pos
-        if event.button != 1: return list_pos
+        if event.type != pygame.MOUSEBUTTONUP or event.button != 1: 
+            return list_pos
         xy = event.pos
-        tmp = self.is_over(xy)
-        if tmp == 1:
+        selected = self.is_over(xy)
+        if selected == 1:
             list_pos -= 1
             if list_pos < 0:
                 list_pos = 0
-        elif tmp == 2:
+        elif selected == 2:
             list_pos += 1
             if list_pos >= len(item_list):
                 list_pos = len(item_list) - 1
-        elif tmp == 3:
+        elif selected == 3:
             list_pos -= self.viewable_items
             if list_pos < 0:
                 list_pos = 0
-        elif tmp == 4:
+        elif selected == 4:
             list_pos += self.viewable_items
             if list_pos >= len(item_list) - 1:
                 list_pos = len(item_list) - 1
